window.Gleam.initSearch([{"doc":"pevensie_redis","title":"pevensie_redis","content":"# Pevensie Redis Driver\n\n[![Package Version](https://img.shields.io/hexpm/v/pevensie_redis)](https://hex.pm/packages/pevensie_redis)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/pevensie_redis/)\n\nThe official Redis-compatible driver for\n[Pevensie](https://github.com/Pevensie/pevensie). It provides driver implementations\nfor Pevensie modules to be used with Redis-compatible databases.\n\nCurrently provides drivers for:\n\n- [Pevensie Cache](https://hexdocs.pm/pevensie/pevensie/cache.html)\n\n## Getting Started\n\nConfigure your driver to connect to your database using the\n[`RedisConfig`](https://hexdocs.pm/pevensie_redis/pevensie/redis.html#RedisConfig)\ntype. You can use the [`default_config`](https://hexdocs.pm/pevensie_redis/pevensie/redis.html#default_config)\nfunction to get a default configuration for connecting to a local\nRedis database with a timeout of 5000 milliseconds.\n\n```gleam\nimport pevensie/redis.{type RedisConfig}\n\npub fn main() {\n  let config = RedisConfig(\n    ..redis.default_config(),\n    host: &quot;cache.pevensie.dev&quot;,\n  )\n  // ...\n}\n```\n\nCreate a new driver using one of the `new_cache_driver` function\nprovided by this module. You can then use the driver with Pevensie\nCache.\n\n```gleam\nimport pevensie/redis.{type RedisConfig}\nimport pevensie/cache\n\npub fn main() {\n  let config = RedisConfig(\n    ..redis.default_config(),\n    host: &quot;cache.pevensie.dev&quot;,\n  )\n  let driver = redis.new_cache_driver(config)\n  let pevensie_auth = cache.new(driver:)\n  // ...\n}\n```\n\n## Connection Management\n\nPevenise Redis uses [radish](https://github.com/gleam-lang/radish) to connect to Redis.\nRadish works by spawning a Gleam OTP actor to for communication with Redis. As such,\nthe [`connect`](https://hexdocs.pm/pevensie/pevensie/cache.html#connect) function provided by Pevensie Cache\nwill start this actor. This can be called once on boot, and will be reused for the lifetime of the application.\n\nThe [`disconnect`](https://hexdocs.pm/pevensie/pevensie/auth.html#disconnect) function\nwill stop the actor.\n\nPevensie Redis uses the [radish](https://github.com/massivefermion/radish) library to\nconnect to Redis. Connection pooling is managed using [Bath](https://github.com/Pevensie/bath).\n\n## Implementation Details\n\nThis driver aims to use Redis in a standard way, and will work with any\nRedis-compatible database (our own test suite uses [Valkey](https://valkey.io/)).\n\n### Pevensie Cache\n\nPevensie Cache uses a combination of a custom resource type and key to identify\nvalues in the cache. In Redis, this is represented as a single key of the form\n`&lt;resource_type&gt;:&lt;key&gt;`.\n\nTTL on `SET` operations is managed via the `EXPIRE` and `PERSIST` commands. When\nthe `ttl_seconds` argument is not `None`, an `EXPIRE` command will be sent\nafter the `SET` operation. When the `ttl_seconds` argument is `None`, a `PERSIST`\ncommand will be sent instead.\n\nBoth will use the `timeout` value provided in the configuration. This means that\n`cache.set`, when called with the Redis driver, may take twice the configured\ntimeout to complete.\n\n## Development\n\nTests rely on a local Redis-compatible database running on port 6379. The repo includes\na `compose.yaml` file to start a local Valkey instance for testing, but feel free to\nuse any Redis-compatible database you&#39;d like.\n\nTests  can be run with:\n\n```bash\ngleam test\n```\n","url":"index.html"},{"doc":"pevensie/redis","title":"Redis","content":"pub opaque type Redis\n The Redis driver.\n\nSynonyms:\npevensie/redis.Redis\npevensie/redis Redis","url":"pevensie/redis.html#Redis"},{"doc":"pevensie/redis","title":"RedisConfig","content":"pub type RedisConfig {\n  RedisConfig(\n    host: String,\n    port: Int,\n    timeout: Int,\n    pool_size: Int,\n    username: Option(String),\n    password: Option(String),\n  )\n}\n Configuration for connecting to a Redis-compatible database.\n\n Use the [`default_config`](#default_config) function to get a default configuration\n for connecting to a local Redis database with sensible defaults.\nRedisConfig(\n  host: String,\n  port: Int,\n  timeout: Int,\n  pool_size: Int,\n  username: Option(String),\n  password: Option(String),\n)\n\n\nSynonyms:\npevensie/redis.RedisConfig\npevensie/redis RedisConfig","url":"pevensie/redis.html#RedisConfig"},{"doc":"pevensie/redis","title":"RedisError","content":"pub type RedisError {\n  StartError(bath.StartError(actor.StartError))\n  ActorError\n  ConnectionError\n  TCPError(mug.Error)\n  ServerError(String)\n  ShutdownError(bath.ShutdownError)\n  PoolError(bath.ApplyError(actor.StartError))\n  UnknownResponseError\n}\n Errors that can occur when interacting with the Postgres driver.\nStartError(bath.StartError(actor.StartError))\n The connection pool failed to start.\n\nActorError\n An error occurred in the underlying OTP actor.\n\nConnectionError\n There was an error connecting to the database.\n\nTCPError(mug.Error)\n A TCP error occurred.\n\nServerError(String)\n An error occurred on the server.\n\nShutdownError(bath.ShutdownError)\n There was an error shutting down the connection pool.\n\nPoolError(bath.ApplyError(actor.StartError))\n There was an error applying a function to the connection pool.\n\nUnknownResponseError\n An unknown response was received from the server.\n\nSynonyms:\npevensie/redis.RedisError\npevensie/redis RedisError","url":"pevensie/redis.html#RedisError"},{"doc":"pevensie/redis","title":"default_config","content":"pub fn default_config() -&gt; RedisConfig\n Returns a default [`RedisConfig`](#RedisConfig) for connecting to a local Redis\n database with sensible defaults.\nSynonyms:\npevensie/redis.default_config\npevensie/redis default_config","url":"pevensie/redis.html#default_config"},{"doc":"pevensie/redis","title":"new_cache_driver","content":"pub fn new_cache_driver(\n  config: RedisConfig,\n) -&gt; CacheDriver(Redis, RedisError)\n Creates a new [`CacheDriver`](/pevensie/drivers/drivers.html#CacheDriver) for use with\n the [`pevensie/cache.new`](/pevensie/cache.html#new) function.\n\n \n import pevensie/redis.{type RedisConfig}\n import pevensie/cache\n\n pub fn main() {\n   let config = RedisConfig(\n     ..redis.default_config(),\n     host: &quot;cache.pevensie.dev&quot;,\n   )\n   let driver = redis.new_cache_driver(config)\n   let pevensie_auth = cache.new(driver:)\n   // ...\n }\n \nSynonyms:\npevensie/redis.new_cache_driver\npevensie/redis new_cache_driver","url":"pevensie/redis.html#new_cache_driver"},{"doc":"pevensie/redis","title":"pevensie/redis","content":"","url":"pevensie/redis.html"}]);